@@ -17,7 +17,8 @@
 testdir="tests"
 tests="installation bad bugs good util"
 CUR=`pwd`
-export TESTPATH="$CUR/$testdir/testarea"
+export RELTESTPATH="$testdir/testarea"
+export TESTPATH="$CUR/$RELTESTPATH"
 export TESTTMP="$CUR/$testdir/testarea/tmp"
 export TESTSTATE="$TESTPATH/lib/ufw"
 
