@@ -206,6 +206,12 @@ class UFWBackend:
             err_msg = _("Invalid option")
             raise UFWError(err_msg)
 
+        # Perform this here so we can present a nice error to the user rather
+        # than a traceback
+        if not os.access(f, os.W_OK):
+            err_msg = _("'%s' is not writable" % (f))
+            raise UFWError(err_msg)
+
         try:
             fns = ufw.util.open_files(f)
         except Exception:
@@ -216,16 +222,19 @@ class UFWBackend:
         pat = re.compile(r'^' + opt + '=')
         for line in fns['orig']:
             if pat.search(line):
-                os.write(fd, opt + "=" + value + "\n")
+                ufw.util.write_to_file(fd, opt + "=" + value + "\n")
                 found = True
             else:
-                os.write(fd, line)
+                ufw.util.write_to_file(fd, line)
 
         # Add the entry if not found
         if not found:
-            os.write(fd, opt + "=" + value + "\n")
+            ufw.util.write_to_file(fd, opt + "=" + value + "\n")
 
-        ufw.util.close_files(fns)
+        try:
+            ufw.util.close_files(fns)
+        except Exception:
+            raise
 
         # Now that the files are written out, update value in memory
         self.defaults[opt.lower()] = value.lower().strip('"\'')
@@ -234,21 +243,33 @@ class UFWBackend:
         '''Sets default application policy of firewall'''
         if not self.dryrun:
             if policy == "allow":
-                self.set_default(self.files['defaults'], \
+                try:
+                    self.set_default(self.files['defaults'], \
                                             "DEFAULT_APPLICATION_POLICY", \
                                             "\"ACCEPT\"")
+                except Exception:
+                    raise
             elif policy == "deny":
-                self.set_default(self.files['defaults'], \
+                try:
+                    self.set_default(self.files['defaults'], \
                                             "DEFAULT_APPLICATION_POLICY", \
                                             "\"DROP\"")
+                except Exception:
+                    raise
             elif policy == "reject":
-                self.set_default(self.files['defaults'], \
+                try:
+                    self.set_default(self.files['defaults'], \
                                             "DEFAULT_APPLICATION_POLICY", \
                                             "\"REJECT\"")
+                except Exception:
+                    raise
             elif policy == "skip":
-                self.set_default(self.files['defaults'], \
+                try:
+                    self.set_default(self.files['defaults'], \
                                             "DEFAULT_APPLICATION_POLICY", \
                                             "\"SKIP\"")
+                except Exception:
+                    raise
             else:
                 err_msg = _("Unsupported policy '%s'") % (policy)
                 raise UFWError(err_msg)
@@ -516,8 +537,8 @@ class UFWBackend:
            else:
                new_level = self.defaults['loglevel']
 
-        self.set_default(self.files['conf'], "LOGLEVEL", new_level)
         try:
+            self.set_default(self.files['conf'], "LOGLEVEL", new_level)
             self.update_logging(new_level)
         except:
             raise
