@@ -57,6 +57,12 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
             self.chains['misc'].append(chain_prefix + "-logging-deny")
             self.chains['misc'].append(chain_prefix + "-logging-allow")
 
+        # The default log rate limiting rule
+        self.ufw_user_limit_log = ['ufw-user-limit', '-m', 'limit', \
+                                   '--limit', '3/minute', '-j', 'LOG', \
+                                   '--log-prefix']
+        self.ufw_user_limit_log_text = "[UFW LIMIT BLOCK]"
+
     def get_default_policy(self, primary="input"):
         '''Get current policy'''
         policy = "default_" + primary + "_policy"
@@ -106,21 +112,30 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
             old_log_str = ''
             new_log_str = ''
             if policy == "allow":
-                self.set_default(self.files['defaults'], \
+                try:
+                    self.set_default(self.files['defaults'], \
                                             "DEFAULT_%s_POLICY" % (chain), \
                                             "\"ACCEPT\"")
+                except Exception:
+                    raise
                 old_log_str = 'UFW BLOCK'
                 new_log_str = 'UFW ALLOW'
             elif policy == "reject":
-                self.set_default(self.files['defaults'], \
+                try:
+                    self.set_default(self.files['defaults'], \
                                             "DEFAULT_%s_POLICY" % (chain), \
                                             "\"REJECT\"")
+                except Exception:
+                    raise
                 old_log_str = 'UFW ALLOW'
                 new_log_str = 'UFW BLOCK'
             else:
-                self.set_default(self.files['defaults'], \
+                try:
+                    self.set_default(self.files['defaults'], \
                                             "DEFAULT_%s_POLICY" % (chain), \
                                             "\"DROP\"")
+                except Exception:
+                    raise
                 old_log_str = 'UFW ALLOW'
                 new_log_str = 'UFW BLOCK'
 
@@ -135,11 +150,14 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
 
                 for line in fns['orig']:
                     if pat.search(line):
-                        os.write(fd, pat.sub(new_log_str, line))
+                        ufw.util.write_to_file(fd, pat.sub(new_log_str, line))
                     else:
-                        os.write(fd, line)
+                        ufw.util.write_to_file(fd, line)
 
-                ufw.util.close_files(fns)
+                try:
+                    ufw.util.close_files(fns)
+                except Exception:
+                    raise
 
         rstr = _("Default %(direction)s policy changed to '%(policy)s'\n") % \
                  ({'direction': direction, 'policy': policy})
@@ -365,6 +383,7 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
         else:
             (rc, out) = cmd([self.files['init'], 'force-stop'])
             if rc != 0:
+                debug(out)
                 raise UFWError(err_msg + " ufw-init")
 
     def start_firewall(self):
@@ -375,6 +394,7 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
         else:
             (rc, out) = cmd([self.files['init'], 'start'])
             if rc != 0:
+                debug(out)
                 raise UFWError(err_msg + " ufw-init")
 
             if not self.defaults.has_key('loglevel') or \
@@ -596,6 +616,12 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
         if v6:
             rules_file = self.files['rules6']
 
+        # Perform this here so we can present a nice error to the user rather
+        # than a traceback
+        if not os.access(rules_file, os.W_OK):
+            err_msg = _("'%s' is not writable" % (rules_file))
+            raise UFWError(err_msg)
+
         try:
             fns = ufw.util.open_files(rules_file)
         except Exception:
@@ -613,17 +639,29 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
             fd = fns['tmp']
 
         # Write header
-        os.write(fd, "*filter\n")
-        os.write(fd, ":" + chain_prefix + "-user-input - [0:0]\n")
-        os.write(fd, ":" + chain_prefix + "-user-output - [0:0]\n")
-        os.write(fd, ":" + chain_prefix + "-user-forward - [0:0]\n")
+        ufw.util.write_to_file(fd, "*filter\n")
+        ufw.util.write_to_file(fd, ":" + chain_prefix + "-user-input - [0:0]\n")
+        ufw.util.write_to_file(fd, ":" + chain_prefix + "-user-output - [0:0]\n")
+        ufw.util.write_to_file(fd, ":" + chain_prefix + "-user-forward - [0:0]\n")
+
+        ufw.util.write_to_file(fd, ":" + chain_prefix + "-before-logging-input - [0:0]\n")
+        ufw.util.write_to_file(fd, ":" + chain_prefix + "-before-logging-output - [0:0]\n")
+        ufw.util.write_to_file(fd, ":" + chain_prefix + "-before-logging-forward - [0:0]\n")
+        ufw.util.write_to_file(fd, ":" + chain_prefix + "-user-logging-input - [0:0]\n")
+        ufw.util.write_to_file(fd, ":" + chain_prefix + "-user-logging-output - [0:0]\n")
+        ufw.util.write_to_file(fd, ":" + chain_prefix + "-user-logging-forward - [0:0]\n")
+        ufw.util.write_to_file(fd, ":" + chain_prefix + "-after-logging-input - [0:0]\n")
+        ufw.util.write_to_file(fd, ":" + chain_prefix + "-after-logging-output - [0:0]\n")
+        ufw.util.write_to_file(fd, ":" + chain_prefix + "-after-logging-forward - [0:0]\n")
+        ufw.util.write_to_file(fd, ":" + chain_prefix + "-logging-deny - [0:0]\n")
+        ufw.util.write_to_file(fd, ":" + chain_prefix + "-logging-allow - [0:0]\n")
 
         if chain_prefix == "ufw":
             # Rate limiting only supported with IPv4
-            os.write(fd, ":" + chain_prefix + "-user-limit - [0:0]\n")
-            os.write(fd, ":" + chain_prefix + "-user-limit-accept - [0:0]\n")
+            ufw.util.write_to_file(fd, ":" + chain_prefix + "-user-limit - [0:0]\n")
+            ufw.util.write_to_file(fd, ":" + chain_prefix + "-user-limit-accept - [0:0]\n")
 
-        os.write(fd, "### RULES ###\n")
+        ufw.util.write_to_file(fd, "### RULES ###\n")
 
         # Write rules
         for r in rules:
@@ -639,7 +677,7 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                     tstr += "_%s" % (r.interface_in)
                 if r.interface_out != "":
                     tstr += "_%s" % (r.interface_out)
-                os.write(fd, tstr + "\n")
+                ufw.util.write_to_file(fd, tstr + "\n")
             else:
                 pat_space = re.compile(' ')
                 dapp = "-"
@@ -656,7 +694,7 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                     tstr += "_%s" % (r.interface_in)
                 if r.interface_out != "":
                     tstr += "_%s" % (r.interface_out)
-                os.write(fd, tstr + "\n")
+                ufw.util.write_to_file(fd, tstr + "\n")
 
             chain_suffix = "input"
             if r.direction == "out":
@@ -666,25 +704,48 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
 
             for s in self._get_rules_from_formatted(rule_str, chain_prefix, \
                                                     chain_suffix):
-                os.write(fd, s)
+                ufw.util.write_to_file(fd, s)
 
         # Write footer
-        os.write(fd, "\n### END RULES ###\n")
+        ufw.util.write_to_file(fd, "\n### END RULES ###\n")
 
+        # Add logging rules, skipping any delete ('-D') rules
+        ufw.util.write_to_file(fd, "\n### LOGGING ###\n")
+        try:
+            lrules_t = self._get_logging_rules(self.defaults['loglevel'])
+        except Exception:
+            raise
+        for c, r, q in lrules_t:
+            if len(r) > 0 and r[0] == '-D':
+                continue
+            if c.startswith(chain_prefix + "-"):
+                ufw.util.write_to_file(fd,
+                    " ".join(r).replace('[', '"[').replace('] ', '] "') + \
+                    "\n")
+        ufw.util.write_to_file(fd, "### END LOGGING ###\n")
+
+        # Rate limiting only supported with IPv4
         if chain_prefix == "ufw":
-            # Rate limiting only supported with IPv4
-            os.write(fd, "-A " + chain_prefix + "-user-limit -m limit " + \
-                         "--limit 3/minute -j LOG --log-prefix " + \
-                         "\"[UFW LIMIT BLOCK] \"\n")
-            os.write(fd, "-A " + chain_prefix + "-user-limit -j REJECT\n")
-            os.write(fd, "-A " + chain_prefix + "-user-limit-accept -j ACCEPT\n")
+            ufw.util.write_to_file(fd, "\n### RATE LIMITING ###\n")
+            if self.defaults['loglevel'] != "off":
+                ufw.util.write_to_file(fd, "-A " + \
+                         " ".join(self.ufw_user_limit_log) + \
+                         " \"" + self.ufw_user_limit_log_text + " \"\n")
+            ufw.util.write_to_file(fd, "-A " + chain_prefix + \
+                         "-user-limit -j REJECT\n")
+            ufw.util.write_to_file(fd, "-A " + chain_prefix + \
+                         "-user-limit-accept -j ACCEPT\n")
+            ufw.util.write_to_file(fd, "### END RATE LIMITING ###\n")
 
-        os.write(fd, "COMMIT\n")
+        ufw.util.write_to_file(fd, "COMMIT\n")
 
-        if self.dryrun:
-            ufw.util.close_files(fns, False)
-        else:
-            ufw.util.close_files(fns)
+        try:
+            if self.dryrun:
+                ufw.util.close_files(fns, False)
+            else:
+                ufw.util.close_files(fns)
+        except Exception:
+            raise
 
     def set_rule(self, rule, allow_reload=True):
         '''Updates firewall with rule by:
@@ -816,6 +877,8 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
         # Update the user rules file
         try:
             self._write_rules(rule.v6)
+        except UFWError:
+            raise
         except Exception:
             err_msg = _("Couldn't update rules file")
             UFWError(err_msg)
@@ -863,7 +926,6 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                 if rule.direction == "out":
                     chain_suffix = "output"
                 chain = "%s-user-%s" % (chain_prefix, chain_suffix)
-          
 
                 # Is the firewall running?
                 err_msg = _("Could not update running firewall")
@@ -929,12 +991,28 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
 
     def update_logging(self, level):
         '''Update loglevel of running firewall'''
-        if not self._is_enabled():
+        if self.dryrun:
             return
 
-        if level not in self.loglevels.keys():
-            err_msg = _("Invalid log level '%s'") % (level)
-            raise UFWError(err_msg)
+        rules_t = []
+        try:
+            rules_t = self._get_logging_rules(level)
+        except Exception:
+            raise
+
+        # Update the user rules file
+        try:
+            self._write_rules(v6=False)
+            self._write_rules(v6=True)
+        except UFWError:
+            raise
+        except Exception:
+            err_msg = _("Couldn't update rules file for logging")
+            UFWError(err_msg)
+
+        # Don't update the running firewall if not enabled
+        if not self._is_enabled():
+            return
 
         # make sure all the chains are here, it's redundant but helps make
         # sure the chains are in a consistent state
@@ -955,18 +1033,48 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
         except:
             raise UFWError(err_msg)
 
+        # Add logging rules to running firewall
+        for c, r, q in rules_t:
+            fail_ok = False
+            if len(r) > 0 and r[0] == '-D':
+                fail_ok = True
+            try:
+                if q == 'delete_first' and len(r) > 1:
+                    self._chain_cmd(c, ['-D'] + r[1:], fail_ok=True)
+                self._chain_cmd(c, r, fail_ok)
+            except Exception:
+                raise UFWError(err_msg)
+
+        # Always delete this and re-add it so that we don't have extras
+        self._chain_cmd('ufw-user-limit', ['-D'] + self.ufw_user_limit_log + \
+                            [self.ufw_user_limit_log_text + " "], \
+                            fail_ok=True)
+
+        if self.defaults["loglevel"] != "off":
+            self._chain_cmd('ufw-user-limit', ['-I'] + \
+                            self.ufw_user_limit_log + \
+                            [self.ufw_user_limit_log_text + " "], \
+                            fail_ok=True)
+
+    def _get_logging_rules(self, level):
+        '''Get rules for specified logging level'''
+        rules_t = []
+
+        if level not in self.loglevels.keys():
+            err_msg = _("Invalid log level '%s'") % (level)
+            raise UFWError(err_msg)
+
         if level == "off":
             # when off, insert a RETURN rule at the top of user rules, thus
             # preserving the rules
             for c in self.chains['user']:
-                self._chain_cmd(c, ['-D', c, '-j', 'RETURN'], fail_ok=True)
-                self._chain_cmd(c, ['-I', c, '-j', 'RETURN'])
-            return
+                rules_t.append([c, ['-I', c, '-j', 'RETURN'], 'delete_first'])
+            return rules_t
         else:
             # when on, remove the RETURN rule at the top of user rules, thus
             # honoring the log rules
             for c in self.chains['user']:
-                self._chain_cmd(c, ['-D', c, '-j', 'RETURN'], fail_ok=True)
+                rules_t.append([c, ['-D', c, '-j', 'RETURN'], ''])
 
         limit_args = ['-m', 'limit', '--limit', '3/min', '--limit-burst', '10']
 
@@ -983,18 +1091,13 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                         if self.get_default_policy(t) == "reject" or \
                            self.get_default_policy(t) == "deny":
                             msg = "[UFW BLOCK] "
-                            try:
-                                self._chain_cmd(c, ['-A', c, '-j', 'LOG', \
-                                                    '--log-prefix', msg] + largs)
-                            except:
-                                raise
+                            rules_t.append([c, ['-A', c, '-j', 'LOG', \
+                                                '--log-prefix', msg] +
+                                                largs, ''])
                         elif self.loglevels[level] >= self.loglevels["medium"]:
                             msg = "[UFW ALLOW] "
-                            try:
-                                self._chain_cmd(c, ['-A', c, '-j', 'LOG', \
-                                                    '--log-prefix', msg] + largs)
-                            except:
-                                raise
+                            rules_t.append([c, ['-A', c, '-j', 'LOG', \
+                                                '--log-prefix', msg] + largs, ''])
 
             # Setup the miscellaneous logging chains
             largs = []
@@ -1007,19 +1110,13 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                     msg = "[UFW ALLOW] "
                 elif c.endswith("deny"):
                     msg = "[UFW BLOCK] "
-                    if self.loglevels[level] >= self.loglevels["medium"]:
+                    if self.loglevels[level] < self.loglevels["medium"]:
                         # only log INVALID in medium and higher
-                        try:
-                            self._chain_cmd(c, ['-I', c, '-m', 'state', \
-                                                '--state', 'INVALID', \
-                                                '-j', 'RETURN'] + largs)
-                        except:
-                            raise
-                try:
-                    self._chain_cmd(c, ['-A', c, '-j', 'LOG', \
-                                        '--log-prefix', msg] + largs)
-                except:
-                    raise
+                        rules_t.append([c, ['-I', c, '-m', 'state', \
+                                            '--state', 'INVALID', \
+                                            '-j', 'RETURN'] + largs, ''])
+                rules_t.append([c, ['-A', c, '-j', 'LOG', \
+                                    '--log-prefix', msg] + largs, ''])
 
         # Setup the audit logging chains
         if self.loglevels[level] >= self.loglevels["medium"]:
@@ -1036,10 +1133,7 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
 
             msg = "[UFW AUDIT] "
             for c in self.chains['before']:
-                try:
-                    self._chain_cmd(c, ['-I', c, '-j', 'LOG', \
-                                        '--log-prefix', msg] + largs)
-                except:
-                    raise UFWError(err_msg)
-
+                rules_t.append([c, ['-I', c, '-j', 'LOG', \
+                                    '--log-prefix', msg] + largs, ''])
 
+        return rules_t
