@@ -1,7 +1,7 @@
 #
 # common.py: common classes for ufw
 #
-# Copyright (C) 2008-2009 Canonical Ltd.
+# Copyright 2008-2009 Canonical Ltd.
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -23,8 +23,10 @@ from ufw.util import debug
 
 programName = "ufw"
 state_dir = "#STATE_PREFIX#"
+trans_dir = "#TRANSLATIONS_PREFIX#"
 config_dir = "#CONFIG_PREFIX#"
 prefix_dir = "#PREFIX#"
+iptables_dir = "#IPTABLES_DIR#"
 
 class UFWError(Exception):
     '''This class represents ufw exceptions'''
@@ -38,7 +40,7 @@ class UFWError(Exception):
 class UFWRule:
     '''This class represents firewall rules'''
     def __init__(self, action, protocol, dport="any", dst="0.0.0.0/0",
-                 sport="any", src="0.0.0.0/0"):
+                 sport="any", src="0.0.0.0/0", direction="in"):
         # Be sure to update dup_rule accordingly...
         self.remove = False
         self.updated = False
@@ -54,6 +56,8 @@ class UFWRule:
         self.action = ""
         self.position = 0
         self.logtype = ""
+        self.interface_in = ""
+        self.interface_out = ""
         try:
             self.set_action(action)
             self.set_protocol(protocol)
@@ -61,6 +65,7 @@ class UFWRule:
             self.set_port(sport, "src")
             self.set_src(src)
             self.set_dst(dst)
+            self.set_direction(direction)
         except UFWError:
             raise
 
@@ -82,18 +87,26 @@ class UFWRule:
         rule.sapp = self.sapp
         rule.position = self.position
         rule.logtype = self.logtype
+        rule.interface_in = self.interface_in
+        rule.interface_out = self.interface_out
+        rule.direction = self.direction
 
         return rule
 
     def format_rule(self):
-        '''Format rule for for later parsing'''
+        '''Format rule for later parsing'''
         str = ""
 
+        if self.interface_in != "":
+            str += " -i %s" % (self.interface_in)
+        if self.interface_out != "":
+            str += " -o %s" % (self.interface_out)
+
         # Protocol is handled below
         if self.protocol == "any":
-            str = " -p all"
+            str += " -p all"
         else:
-            str = " -p " + self.protocol
+            str += " -p " + self.protocol
 
             if self.multi:
                 str += " -m multiport"
@@ -239,7 +252,7 @@ class UFWRule:
                 self.src = "0.0.0.0/0"
 
     def set_v6(self, v6):
-        '''Sets whether this is ipv6 rule, and adjusts src and dst 
+        '''Sets whether this is ipv6 rule, and adjusts src and dst
            accordingly.
         '''
         self.v6 = v6
@@ -265,6 +278,25 @@ class UFWRule:
         self.dst = tmp
         self._fix_anywhere()
 
+    def set_interface(self, type, name):
+        '''Sets an interface for rule'''
+        if type != "in" and type != "out":
+            err_msg = _("Bad interface type")
+            raise UFWError(err_msg)
+
+        if not re.match(r'^[a-zA-Z][a-zA-Z0-9:]*[0-9]', str(name)):
+            err_msg = _("Bad interface name")
+            raise UFWError(err_msg)
+
+        if ':' in str(name):
+            err_msg = _("Bad interface name: can't use interface aliases")
+            raise UFWError(err_msg)
+
+        if type == "in":
+            self.interface_in = name
+        else:
+            self.interface_out = name
+
     def set_position(self, num):
         '''Sets the position of the rule'''
         if not re.match(r'^[0-9]+', str(num)):
@@ -281,6 +313,14 @@ class UFWRule:
             err_msg = _("Invalid log type '%s'") % (logtype)
             raise UFWError(err_msg)
 
+    def set_direction(self, direction):
+        '''Sets direction of the rule'''
+        if direction == "in" or direction == "out":
+            self.direction = direction
+        else:
+            err_msg = _("Unsupported direction '%s'") % (direction)
+            raise UFWError(err_msg)
+
     def normalize(self):
         '''Normalize src and dst to standard form'''
         changed = False
@@ -351,17 +391,34 @@ class UFWRule:
         if x.sapp != y.sapp:
             debug(dbg_msg)
             return 1
+        if x.interface_in != y.interface_in:
+            return 1
+        if x.interface_out != y.interface_out:
+            return 1
+        if x.direction != y.direction:
+            return 1
         if x.action == y.action and x.logtype == y.logtype:
             dbg_msg = _("Found exact match")
             debug(dbg_msg)
             return 0
-        dbg_msg = _("Found non-action/non-logtype match (%s/%s %s/%s)") % \
-                    (x.action, y.action, x.logtype, y.logtype)
+        dbg_msg = _("Found non-action/non-logtype match " \
+                    "(%(xa)s/%(ya)s %(xl)s/%(yl)s)") % \
+                    ({'xa': x.action, 'ya': y.action, \
+                      'xl': x.logtype, 'yl': y.logtype})
         debug(dbg_msg)
         return -1
 
     def get_app_tuple(self):
-        '''Returns a tuple to identify an app rule'''
+        '''Returns a tuple to identify an app rule. Tuple is:
+             dapp dst sapp src
+           or
+             dport dst sapp src
+           or
+             dapp dst sport src
+
+           All of these might have in_eth0 out_eth0 (or similar) if an
+           interface is also defined.
+        '''
         tuple = ""
         if self.dapp != "" or self.sapp != "":
             tuple = "%s %s %s %s" % (self.dapp, self.dst, self.sapp, self.src)
@@ -372,5 +429,11 @@ class UFWRule:
                 tuple = "%s %s %s %s" % (self.dapp, self.dst, self.sport, \
                                          self.src)
 
+            # add interfaces to the end, if they exist
+            if self.interface_in != "":
+                tuple += " in_%s" % (self.interface_in)
+            if self.interface_out != "":
+                tuple += " out_%s" % (self.interface_out)
+
         return tuple
 
