@@ -1,6 +1,6 @@
 #!/bin/bash
 
-#    Copyright (C) 2008-2009 Canonical Ltd.
+#    Copyright 2008-2009 Canonical Ltd.
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -22,11 +22,13 @@ do_cmd "1" null --dry-run logging foo
 do_cmd "1" null --dry-run loggin on
 
 echo "TESTING ARGS (default)" >> $TESTTMP/result
-do_cmd "1" null --dry-run default
-do_cmd "1" null --dry-run default foo
-do_cmd "1" null --dry-run default accept
-do_cmd "1" null --dry-run defaul allow
-do_cmd "1" null --dry-run default limit
+for i in "" "input" "incoming" "output" "outgoing"; do
+    do_cmd "1" null --dry-run default $i
+    do_cmd "1" null --dry-run default foo $i
+    do_cmd "1" null --dry-run default accept $i
+    do_cmd "1" null --dry-run defaul allow $i
+    do_cmd "1" null --dry-run default limit $i
+done
 
 echo "TESTING ARGS (enable/disable)" >> $TESTTMP/result
 # bad
@@ -252,4 +254,23 @@ do_cmd "0" null insert 1 allow log 22
 do_cmd "0" null delete allow 22
 do_cmd "0" null delete allow 23
 
+echo "TESTING ARGS (interfaces)" >> $TESTTMP/result
+for j in "in" "out"; do
+    for i in allow deny limit; do
+        do_cmd "1" null --dry-run $i $j on eth0:1
+        do_cmd "1" null --dry-run $i $j on e%th0
+        do_cmd "1" null --dry-run $i on eth0
+        do_cmd "1" null --dry-run $i ina on eth0
+        do_cmd "1" null --dry-run $i $j ona eth0
+        do_cmd "1" null --dry-run $i $j eth0
+        do_cmd "1" null --dry-run $i $j on eth0 to
+        do_cmd "1" null --dry-run $i $j on eth0 from
+        do_cmd "1" null --dry-run $i $j on eth0 from any to
+        do_cmd "1" null --dry-run $i $j on eth0 any from
+        do_cmd "1" null --dry-run $i $j on eth0 any from to any proto
+        do_cmd "1" null --dry-run $i log $j on eth0
+        do_cmd "1" null --dry-run $i log-all $j on eth0
+    done
+done
+
 exit 0
