@@ -87,4 +87,66 @@ rm -f "$TESTPATH/etc/ufw/applications.d/bug407810"
 do_cmd "0" null delete allow bug407810
 grep "^-A .*user-input" $TESTSTATE/user.rules >> $TESTTMP/result
 
+echo "Bug #430053" >> $TESTTMP/result
+# files permissions are overridden when root
+expected="1"
+if [ "$UID" = "0" ]; then
+    expected="0"
+fi
+sed -i 's/IPV6=.*/IPV6=no/' $TESTPATH/etc/default/ufw
+chmod 444 $TESTSTATE/user.rules
+do_cmd "$expected" null allow 12345
+chmod 644 $TESTSTATE/user.rules
+
+sed -i 's/IPV6=.*/IPV6=yes/' $TESTPATH/etc/default/ufw
+chmod 444 $TESTSTATE/user6.rules
+do_cmd "$expected" null allow 12345
+chmod 644 $TESTSTATE/user6.rules
+sed -i 's/IPV6=.*/IPV6=no/' $TESTPATH/etc/default/ufw
+
+chmod 444 $TESTPATH/etc/default/ufw
+do_cmd "$expected" null default deny
+chmod 644 $TESTPATH/etc/default/ufw
+
+chmod 444 $TESTPATH/etc/ufw/ufw.conf
+do_cmd "$expected" null logging medium
+chmod 644 $TESTPATH/etc/ufw/ufw.conf
+
+echo "Bug #480789" >> $TESTTMP/result
+sed -i 's/IPV6=.*/IPV6=yes/' $TESTPATH/etc/default/ufw
+for i in low on medium high full ; do
+    do_cmd "0" null --dry-run logging $i
+    e="1"
+    if [ "$i" = "low" ] || [ "$i" = "on" ]; then
+        e="0"
+    fi
+    do_cmd "0" nostats allow 22
+    for j in user.rules user6.rules ; do
+        echo "checking for 'INVALID -j RETURN' in $j" >> $TESTTMP/result
+        grep -q 'logging-deny .* INVALID -j RETURN' $TESTPATH/lib/ufw/$j
+        rc="$?"
+        if [ "$rc" != "$e" ]; then
+            echo "$i: got '$rc', expected '$e'"
+            exit 1
+        fi
+    done
+    do_cmd "0" nostats delete allow 22
+done
+sed -i 's/IPV6=.*/IPV6=yes/' $TESTPATH/etc/default/ufw
+
+echo "Bug #512131" >> $TESTTMP/result
+for i in off low on medium high full off ; do
+    do_cmd "0" null logging $i
+    e="0"
+    if [ "$i" = "off" ]; then
+        e="1"
+    fi
+    grep -q 'UFW LIMIT BLOCK' $TESTPATH/lib/ufw/user.rules
+    rc="$?"
+    if [ "$rc" != "$e" ]; then
+        echo "$i: got '$rc', expected '$e'"
+        exit 1
+    fi
+done
+
 exit 0
