@@ -1,6 +1,6 @@
 #!/bin/bash
 
-#    Copyright (C) 2008-2009 Canonical Ltd.
+#    Copyright 2008-2009 Canonical Ltd.
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -120,30 +120,54 @@ do_cmd "0" null allow Apache
 do_cmd "0" null allow Bind9
 do_cmd "0" null insert 1 allow Samba
 do_cmd "0" null insert 2 reject 'Dovecot POP3'
-cat $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+cat $TESTSTATE/user.rules >> $TESTTMP/result
 
 do_cmd "0" null delete allow Apache
 do_cmd "0" null delete allow Bind9
 do_cmd "0" null delete allow Samba
 do_cmd "0" null delete reject 'Dovecot POP3'
-cat $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+cat $TESTSTATE/user.rules >> $TESTTMP/result
 
 do_cmd "0" null allow Samba
 do_cmd "0" null allow 22
-do_cmd "0" null insert 2 allow from any to any app Samba
+do_cmd "0" null insert 2 allow log-all from any to any app Samba
 do_cmd "0" null insert 2 allow from 192.168.0.1 to 10.0.0.1 app Samba
 do_cmd "0" null insert 2 allow from 192.168.0.1 to any app Samba
 do_cmd "0" null insert 2 allow from 192.168.0.1 app Samba to 10.0.0.1
 do_cmd "0" null insert 2 allow from any app Samba to 10.0.0.1
-cat $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+cat $TESTSTATE/user.rules >> $TESTTMP/result
 
 do_cmd "0" null delete allow Samba
 do_cmd "0" null delete allow 22
-do_cmd "0" null delete allow from any to any app Samba
+do_cmd "0" null delete allow log-all from any to any app Samba
 do_cmd "0" null delete allow from 192.168.0.1 to 10.0.0.1 app Samba
 do_cmd "0" null delete allow from 192.168.0.1 to any app Samba
 do_cmd "0" null delete allow from 192.168.0.1 app Samba to 10.0.0.1
 do_cmd "0" null delete allow from any app Samba to 10.0.0.1
-cat $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+cat $TESTSTATE/user.rules >> $TESTTMP/result
+
+echo "TESTING APPLICATION INTEGRATION (interfaces)" >> $TESTTMP/result
+for i in "in" "out" ; do
+    for j in allow deny limit reject ; do
+        do_cmd "0" null $j $i on eth0 to 192.168.0.1 app Samba
+        do_cmd "0" null $j $i on eth0 from 10.0.0.1 app Samba
+        do_cmd "0" null $j $i on eth0 from 10.0.0.1 to any app Samba
+        cat $TESTSTATE/user.rules >> $TESTTMP/result
+
+        do_cmd "0" null delete $j $i on eth0 to 192.168.0.1 app Samba
+        do_cmd "0" null delete $j $i on eth0 from 10.0.0.1 app Samba
+        do_cmd "0" null delete $j $i on eth0 from 10.0.0.1 to any app Samba
+        cat $TESTSTATE/user.rules >> $TESTTMP/result
+    done
+    do_cmd "0" null allow $i on eth0 to any app Samba
+    do_cmd "0" null allow $i on eth1 to any port 22
+    do_cmd "0" null insert 2 allow $i on eth2 to any app Samba
+    cat $TESTSTATE/user.rules >> $TESTTMP/result
+
+    do_cmd "0" null delete allow $i on eth0 to any app Samba
+    do_cmd "0" null delete allow $i on eth1 to any port 22
+    do_cmd "0" null delete allow $i on eth2 to any app Samba
+    cat $TESTSTATE/user.rules >> $TESTTMP/result
+done
 
 exit 0
