@@ -74,7 +74,7 @@ done
 echo "Checking status" >> $TESTTMP/result
 do_cmd "0" null status
 do_cmd "0" null status verbose
-do_cmd "0" null status raw
+do_cmd "0" null status numbered
 
 echo "Checking reject" >> $TESTTMP/result
 for ipv6 in yes no
@@ -104,11 +104,11 @@ do
         do_cmd "0" nostats disable
         sed -i "s/MANAGE_BUILTINS=.*/MANAGE_BUILTINS=$ans/" $TESTPATH/etc/default/ufw
 
-        iptables -D INPUT -j ACCEPT -m comment --comment $str 2>/dev/null
         echo iptables -I INPUT -j ACCEPT -m comment --comment $str >> $TESTTMP/result
         iptables -I INPUT -j ACCEPT -m comment --comment $str >> $TESTTMP/result
         do_cmd "0" nostats enable
         iptables -n -L INPUT | grep "$str" >> $TESTTMP/result
+        iptables -D INPUT -j ACCEPT -m comment --comment $str 2>/dev/null
 done
 
 echo "Testing status numbered" >> $TESTTMP/result
@@ -203,6 +203,129 @@ do
 	grep -A2 "tuple" $TESTSTATE/user6.rules >> $TESTTMP/result
     done
 done
+
+echo "Compare enable and ufw-init" >> $TESTTMP/result
+sed -i "s/IPV6=.*/IPV6=yes/" $TESTPATH/etc/default/ufw
+do_cmd "0" nostats disable
+do_cmd "0" nostats allow 23/tcp
+do_cmd "0" nostats logging medium
+do_cmd "0" null enable
+iptables-save | grep '^-' > $TESTTMP/ipt.enable
+ip6tables-save | grep '^-' > $TESTTMP/ip6t.enable
+
+do_cmd "0" null disable
+iptables-save | grep '^-' > $TESTTMP/ipt.disable
+ip6tables-save | grep '^-' > $TESTTMP/ip6t.disable
+
+sed -i 's/^ENABLED=no/ENABLED=yes/' $TESTPATH/etc/ufw/ufw.conf
+do_extcmd "0" null $RELTESTPATH/lib/ufw/ufw-init start
+iptables-save | grep '^-' > $TESTTMP/ipt.start
+ip6tables-save | grep '^-' > $TESTTMP/ip6t.start
+
+do_extcmd "0" null $RELTESTPATH/lib/ufw/ufw-init stop
+iptables-save | grep '^-' > $TESTTMP/ipt.stop
+ip6tables-save | grep '^-' > $TESTTMP/ip6t.stop
+
+diff $TESTTMP/ipt.enable $TESTTMP/ipt.start || {
+	echo "'ufw enable' and 'ufw-init start' are different"
+	exit 1
+}
+
+diff $TESTTMP/ip6t.enable $TESTTMP/ip6t.start || {
+	echo "'ufw enable' and 'ufw-init start' are different (ipv6)"
+	exit 1
+}
+
+diff $TESTTMP/ipt.disable $TESTTMP/ipt.stop || {
+	echo "'ufw disable' and 'ufw-init stop' are different"
+	exit 1
+}
+
+diff $TESTTMP/ip6t.disable $TESTTMP/ip6t.stop || {
+	echo "'ufw disable' and 'ufw-init stop' are different (ipv6)"
+	exit 1
+}
+do_cmd "0" nostats enable
+do_cmd "0" nostats delete allow 23/tcp
+do_cmd "0" nostats logging low
+do_cmd "0" nostats disable
+sed -i "s/IPV6=.*/IPV6=no/" $TESTPATH/etc/default/ufw
+
+echo "Verify toplevel chains" >> $TESTTMP/result
+for l in off on low medium high full; do
+    do_cmd "0" nostats logging $l
+    do_cmd "0" nostats disable
+    $TESTSTATE/ufw-init flush-all >> $TESTTMP/result 2>&1
+    do_cmd "0" nostats enable
+    for b in INPUT OUTPUT FORWARD; do
+        for c in before-logging before after after-logging reject track ; do
+            if [ "$b" = "FORWARD" ] && [ "$c" = "track" ]; then
+                # FORWARD doesn't have the ufw-track-forward chain
+                continue
+            fi
+            suffix=`echo $b | tr [A-Z] [a-z]`
+            echo "$count: iptables -L $b -n | egrep -q 'ufw-$c-$suffix'" >> $TESTTMP/result
+            iptables -L $b -n | egrep -q "ufw-$c-$suffix" || {
+                echo "'iptables -L $b -n' does not contain 'ufw-$c-$suffix'"
+                exit 1
+            }
+            echo "" >> $TESTTMP/result
+            echo "" >> $TESTTMP/result
+            let count=count+1
+        done
+    done
+done
+
+echo "Verify secondary chains" >> $TESTTMP/result
+for l in off on low medium high full; do
+    do_cmd "0" nostats logging $l
+    do_cmd "0" nostats disable
+    $TESTSTATE/ufw-init flush-all >> $TESTTMP/result 2>&1
+    do_cmd "0" nostats enable
+    for c in logging-deny not-local user-forward user-input user-output skip-to-policy-input ; do
+        echo "$count: ! iptables -L ufw-$c -n | egrep -q '0 references'" >> $TESTTMP/result
+        iptables -L ufw-$c -n | egrep -q '0 references' && {
+            echo "'iptables -L ufw-user-input -n' had 0 references"
+            exit 1
+        }
+        echo "" >> $TESTTMP/result
+        echo "" >> $TESTTMP/result
+        let count=count+1
+    done
+    for c in logging-allow user-limit user-limit-accept user-logging-forward user-logging-input user-logging-output skip-to-policy-output skip-to-policy-forward ; do
+        echo "$count: iptables -L ufw-$c -n | egrep -q '0 references'" >> $TESTTMP/result
+        iptables -L ufw-$c -n | egrep -q '0 references' || {
+            echo "'iptables -L ufw-user-input -n' had more than 0 references"
+            exit 1
+        }
+        echo "" >> $TESTTMP/result
+        echo "" >> $TESTTMP/result
+        let count=count+1
+    done
+done
+do_cmd "0" nostats logging on
+do_cmd "0" nostats disable
+
+echo "'Resource temporarily unavailable' test" >> $TESTTMP/result
+do_cmd "0" nostats disable
+$TESTSTATE/ufw-init flush-all >/dev/null
+do_cmd "0" nostats allow 22/tcp
+do_cmd "0" nostats enable
+$TESTSTATE/ufw-init stop >/dev/null
+for i in `seq 1 25`; do
+    echo "$count: ufw-init start/flush-all" >> $TESTTMP/result
+    $TESTSTATE/ufw-init start >/dev/null || {
+        echo "'ufw-init start' failed"
+        exit 1
+    }
+    $TESTSTATE/ufw-init flush-all >/dev/null
+    echo "" >> $TESTTMP/result
+    echo "" >> $TESTTMP/result
+    let count=count+1
+done
+do_cmd "0" nostats enable
+do_cmd "0" nostats delete allow 22/tcp
+
 cleanup
 
 exit 0
