@@ -1,6 +1,6 @@
 #!/bin/bash
 
-#    Copyright (C) 2008-2009 Canonical Ltd.
+#    Copyright 2008-2009 Canonical Ltd.
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -32,8 +32,8 @@ do
 
 	echo "Setting IPV6 to $ipv6" >> $TESTTMP/result
 	sed -i "s/IPV6=.*/IPV6=$ipv6/" $TESTPATH/etc/default/ufw
-	do_cmd "0"  disable
-	do_cmd "0"  enable
+	do_cmd "0" nostats disable
+	do_cmd "0" nostats enable
 
 	do_cmd "0"  allow Apache
 	for loc in any addr ; do
@@ -87,8 +87,8 @@ sed -i 's/8888/80/g' $TESTPATH/etc/ufw/applications.d/apache
 echo "TESTING APPLICATION RULES (v6 delete app rules)" >> $TESTTMP/result
 echo "Setting IPV6 to yes" >> $TESTTMP/result
 sed -i "s/IPV6=.*/IPV6=yes/" $TESTPATH/etc/default/ufw
-do_cmd "0"  disable
-do_cmd "0"  enable
+do_cmd "0" nostats disable
+do_cmd "0" nostats enable
 do_cmd "0"  allow Apache
 do_cmd "0"  allow from 2001:db8::/32 to any app Apache
 do_cmd "0" status verbose
@@ -156,19 +156,19 @@ echo "TESTING INSERT" >> $TESTTMP/result
 for ipv6 in no yes ; do
     echo "Setting IPV6 to $ipv6" >> $TESTTMP/result
     sed -i "s/IPV6=.*/IPV6=$ipv6/" $TESTPATH/etc/default/ufw
-    do_cmd "0"  disable
-    do_cmd "0"  enable
+    do_cmd "0" nostats disable
+    do_cmd "0" nostats enable
     do_cmd "0" allow Apache
     do_cmd "0" allow Bind9
     do_cmd "0" insert 1 allow Samba
     do_cmd "0" insert 2 reject 'Dovecot POP3'
-    cat $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
-    cat $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+    cat $TESTSTATE/user.rules >> $TESTTMP/result
+    cat $TESTSTATE/user6.rules >> $TESTTMP/result
 
     iptables-save | egrep -v '^(#|:)' > $TESTTMP/save.1
     ip6tables-save | egrep -v '^(#|:)' >> $TESTTMP/save.1
-    do_cmd "0"  disable
-    do_cmd "0"  enable
+    do_cmd "0" nostats disable
+    do_cmd "0" nostats enable
     iptables-save | egrep -v '^(#|:)' > $TESTTMP/save.2
     ip6tables-save | egrep -v '^(#|:)' >> $TESTTMP/save.2
     diff $TESTTMP/save.1 $TESTTMP/save.2 || {
@@ -180,8 +180,8 @@ for ipv6 in no yes ; do
     do_cmd "0" delete allow Bind9
     do_cmd "0" delete allow Samba
     do_cmd "0" delete reject 'Dovecot POP3'
-    cat $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
-    cat $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+    cat $TESTSTATE/user.rules >> $TESTTMP/result
+    cat $TESTSTATE/user6.rules >> $TESTTMP/result
 
     do_cmd "0" allow Samba
     do_cmd "0" allow 22
@@ -190,13 +190,13 @@ for ipv6 in no yes ; do
     do_cmd "0" insert 2 allow from 192.168.0.1 to any app Samba
     do_cmd "0" insert 2 allow from 192.168.0.1 app Samba to 10.0.0.1
     do_cmd "0" insert 2 allow from any app Samba to 10.0.0.1
-    cat $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
-    cat $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+    cat $TESTSTATE/user.rules >> $TESTTMP/result
+    cat $TESTSTATE/user6.rules >> $TESTTMP/result
 
     iptables-save | egrep -v '^(#|:)' > $TESTTMP/save.1
     ip6tables-save | egrep -v '^(#|:)' >> $TESTTMP/save.1
-    do_cmd "0"  disable
-    do_cmd "0"  enable
+    do_cmd "0" nostats disable
+    do_cmd "0" nostats enable
     iptables-save | egrep -v '^(#|:)' > $TESTTMP/save.2
     ip6tables-save | egrep -v '^(#|:)' >> $TESTTMP/save.2
     diff $TESTTMP/save.1 $TESTTMP/save.2 || {
@@ -211,8 +211,37 @@ for ipv6 in no yes ; do
     do_cmd "0" delete allow from 192.168.0.1 to any app Samba
     do_cmd "0" delete allow from 192.168.0.1 app Samba to 10.0.0.1
     do_cmd "0" delete allow from any app Samba to 10.0.0.1
-    cat $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
-    cat $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+    cat $TESTSTATE/user.rules >> $TESTTMP/result
+    cat $TESTSTATE/user6.rules >> $TESTTMP/result
+done
+
+echo "TESTING APPLICATION INTEGRATION (interfaces)" >> $TESTTMP/result
+for i in "in" "out" ; do
+    for j in allow deny limit reject ; do
+        do_cmd "0" $j $i on eth0 to 192.168.0.1 app Samba
+        do_cmd "1" null $j $i on eth0:1 from 10.0.0.1 app Samba
+        do_cmd "0" $j $i on eth0 from 10.0.0.1 to any app Samba
+        do_cmd "0" status
+        grep -A3 "tuple" $TESTSTATE/user.rules >> $TESTTMP/result
+        grep -A3 "tuple" $TESTSTATE/user6.rules >> $TESTTMP/result
+
+        do_cmd "0" delete $j $i on eth0 to 192.168.0.1 app Samba
+        do_cmd "0" delete $j $i on eth0 from 10.0.0.1 to any app Samba
+        do_cmd "0" status
+        grep -A3 "tuple" $TESTSTATE/user.rules >> $TESTTMP/result
+        grep -A3 "tuple" $TESTSTATE/user6.rules >> $TESTTMP/result
+    done
+    do_cmd "0" allow $i on eth0 to any app Bind9
+    do_cmd "0" insert 1 allow $i on eth2 to any app Samba
+    do_cmd "0" status
+    grep -A2 "tuple" $TESTSTATE/user.rules >> $TESTTMP/result
+    grep -A2 "tuple" $TESTSTATE/user6.rules >> $TESTTMP/result
+
+    do_cmd "0" delete allow $i on eth0 to any app Bind9
+    do_cmd "0" delete allow $i on eth2 to any app Samba
+    do_cmd "0" status
+    grep -A2 "tuple" $TESTSTATE/user.rules >> $TESTTMP/result
+    grep -A2 "tuple" $TESTSTATE/user6.rules >> $TESTTMP/result
 done
 
 cleanup
